namespace FitConnect;

public class FitConnectEndpoints {
    public enum EndpointType {
        Development,
        Testing,
        Production
    }

    private static readonly FitConnectEndpoints DevEndpoints = new(
        "https://auth-testing.fit-connect.fitko.dev/token",
        "https://submission-api-testing.fit-connect.fitko.dev",
        "https://routing-api-testing.fit-connect.fitko.dev"
    );

    private static readonly FitConnectEndpoints TestEndpoints = new(
        "https://auth-testing.fit-connect.fitko.dev/token",
        "https://submission-api-testing.fit-connect.fitko.dev",
        "https://routing-api-testing.fit-connect.fitko.dev"
    );

    private static readonly FitConnectEndpoints ProductionEndpoints = new(
        "https://auth-testing.fit-connect.fitko.dev/token",
        "https://submission-api-testing.fit-connect.fitko.dev",
        "https://routing-api-testing.fit-connect.fitko.dev"
    );

    /// <summary>
    ///     Default constructor.
    /// </summary>
    /// <param name="tokenUrl">URL for receiving the OAuth token</param>
    /// <param name="submissionUrl">URL for the submission API</param>
    /// <param name="routingUrl">URL for the routing API</param>
    public FitConnectEndpoints(string tokenUrl, string submissionUrl, string routingUrl) {
        TokenUrl = tokenUrl;
        SubmissionUrl = submissionUrl;
        RoutingUrl = routingUrl;
    }

    /// <summary>
    ///     URL for receiving the OAuth token.
    /// </summary>
    public string TokenUrl { get; }

    /// <summary>
    ///     URL for the submission API.
    /// </summary>
    public string SubmissionUrl { get; }

    /// <summary>
    ///     URL for the routing API.
    /// </summary>
    public string RoutingUrl { get; }

    /// <summary>
    ///     Creates the endpoints for the given environment.
    /// </summary>
    /// <param name="endpointType">Environment to get endpoints for</param>
    /// <returns></returns>
    /// <exception cref="ArgumentException">Not all environments are ready to use</exception>
    public static FitConnectEndpoints Create(EndpointType endpointType) {
        return endpointType switch {
            EndpointType.Development => DevEndpoints,
            EndpointType.Testing => throw new ArgumentException("Not approved for online testing"),
            EndpointType.Production => throw new ArgumentException("NOT PRODUCTION READY"),
            _ => throw new ArgumentOutOfRangeException(nameof(endpointType), endpointType, null)
        };
    }
}
